# Contributor Covenant Code of Conduct

## Our Pledge

We value the participation of every contributor and want this project to be a welcoming and supportive environment for all.

## Our Standards

Examples of behavior that contributes to a positive environment include:

- Using welcoming and inclusive language.
- Being respectful of differing viewpoints and experiences.
- Gracefully accepting constructive criticism.
- Focusing on what is best for the community.

Examples of unacceptable behavior include:

- Harassment, intimidation, or discrimination.
- Unwelcome sexual attention or advances.
- Trolling or insulting/derogatory comments.
- Public or private harassment of any contributor.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by opening an issue or contacting the project maintainers at [your-email@example.com]. All complaints will be reviewed and investigated promptly and fairly.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org).
